@@ -1,13 +1,13 @@
 package Perinci::Sub::Gen::AccessTable;
 
-our $DATE = '2016-02-13'; # DATE
-our $VERSION = '0.55'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.56'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use Function::Fallback::CoreOrPP qw(clone);
 use List::Util qw(shuffle);
@@ -460,6 +460,8 @@ _
     my $ea = $opts->{extra_args} // {};
     $func_args->{$_} = $ea->{$_} for keys %$ea;
 
+    use DDC; dd $func_meta;
+
     [200, "OK", $func_meta];
 }
 
@@ -671,7 +673,7 @@ sub __parse_query {
     $query->{result_limit} = $args->{result_limit};
     $query->{result_start} = $args->{result_start} // 1;
 
-    $log->tracef("parsed query: %s", $query);
+    log_trace("parsed query: %s", $query);
     [200, "OK", $query];
 }
 
@@ -761,7 +763,7 @@ sub _gen_func {
 
         no warnings; # silence undef warnings when comparing record values
 
-        $log->tracef("(read_table_func) Filtering ...");
+        log_trace("(read_table_func) Filtering ...");
         my $q = $query->{query};
         my $search_re = $query->{search_re};
 
@@ -914,7 +916,7 @@ sub _gen_func {
             push @r, $r_h;
         }
 
-        $log->tracef("(read_table_func) Ordering ...");
+        log_trace("(read_table_func) Ordering ...");
         if ($metadata->{sorted}) {
             # do nothing
         } elsif ($query->{random}) {
@@ -941,7 +943,7 @@ sub _gen_func {
         use experimental 'smartmatch';
 
         # perform paging
-        $log->tracef("(read_table_func) Paging ...");
+        log_trace("(read_table_func) Paging ...");
         unless ($metadata->{paged}) {
             if ($query->{result_start} > 1) {
                 splice @r, 0, $query->{result_start}-1;
@@ -952,7 +954,7 @@ sub _gen_func {
         }
 
         # select fields
-        $log->tracef("(read_table_func) Selecting fields ...");
+        log_trace("(read_table_func) Selecting fields ...");
         my $pk = $table_spec->{pk};
         goto SKIP_SELECT_FIELDS if $metadata->{fields_selected};
       REC2:
@@ -1464,7 +1466,7 @@ sub gen_read_table_func {
     if ($args{install} // 1) {
         no strict 'refs';
         no warnings;
-        $log->tracef("Installing function as %s ...", $fqname);
+        log_trace("Installing function as %s ...", $fqname);
         *{ $fqname } = $func;
         ${$package . "::SPEC"}{$uqname} = $func_meta;
     }
@@ -1487,7 +1489,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its metadata) to read ta
 
 =head1 VERSION
 
-This document describes version 0.55 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2016-02-13.
+This document describes version 0.56 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -1598,7 +1600,11 @@ It is often not a good idea to expose your database schema directly as API.
 =head1 FUNCTIONS
 
 
-=head2 gen_read_table_func(%args) -> [status, msg, result, meta]
+=head2 gen_read_table_func
+
+Usage:
+
+ gen_read_table_func(%args) -> [status, msg, result, meta]
 
 Generate function (and its metadata) to read table data.
 
@@ -1963,7 +1969,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-Gen-AccessTable>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-Gen-AccessTable>.
 
 =head1 BUGS
 
@@ -1985,7 +1991,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
